uk_custom_avatar library
Provides a customizable avatar widget with image fallback and styling options.
Part of the uk_custom_widget package.
Provides a customizable avatar widget with image fallback and styling options.
Part of the uk_custom_widget package.